@@ -44,6 +44,15 @@
 							ExpressionItem *copy() const {return new x(this);} \
 							int id() const {return i;}\
 						};
+#define DECLARE_BUILTIN_FUNCTION_P(x, i)	class x : public MathFunction { \
+						  public: \
+							int calculate(MathStructure &mstruct, const MathStructure &vargs, const EvaluationOptions &eo);  \
+							x(); \
+							x(const x *function) {set(function);} \
+							ExpressionItem *copy() const {return new x(this);} \
+							int id() const {return i;}\
+							int parse(MathStructure &mstruct, const std::string &eq, const ParseOptions &po = default_parse_options);\
+						};
 
 #define DECLARE_BUILTIN_FUNCTION_M(x, i)	class x : public MathFunction { \
 						  public: \
@@ -137,6 +146,20 @@
 							int id() const {return i;}\
 						};
 
+#define DECLARE_BUILTIN_FUNCTION_R4(x, i)	class x : public MathFunction { \
+						  public: \
+							int calculate(MathStructure &mstruct, const MathStructure &vargs, const EvaluationOptions &eo);  \
+							x(); \
+							x(const x *function) {set(function);} \
+							ExpressionItem *copy() const {return new x(this);} \
+							bool representsNumber(const MathStructure &vargs, bool allow_units = false) const;\
+							bool representsReal(const MathStructure &vargs, bool allow_units = false) const;\
+							bool representsNonComplex(const MathStructure &vargs, bool allow_units = false) const;\
+							bool representsUndefined(const MathStructure &vargs) const;\
+							TEST_NM_S_FUNCTIONS\
+							int id() const {return i;}\
+						};
+
 #define DECLARE_BUILTIN_FUNCTION_R3(x, i)	class x : public MathFunction { \
 						  public: \
 							int calculate(MathStructure &mstruct, const MathStructure &vargs, const EvaluationOptions &eo);  \
@@ -205,6 +228,9 @@ enum {
 	FUNCTION_ID_NORM = 1138,
 	FUNCTION_ID_VERTCAT = 1139,
 	FUNCTION_ID_HORZCAT = 1140,
+	FUNCTION_ID_KRONECKER_PRODUCT = 1141,
+	FUNCTION_ID_COLON = 1142,
+	FUNCTION_ID_FLIP = 1143,
 	FUNCTION_ID_SQRT = 1200,
 	FUNCTION_ID_CBRT = 1201,
 	FUNCTION_ID_ROOT = 1202,
@@ -214,6 +240,8 @@ enum {
 	FUNCTION_ID_LOGN = 1206,
 	FUNCTION_ID_LAMBERT_W = 1207,
 	FUNCTION_ID_CIS = 1208,
+	FUNCTION_ID_POWER_TOWER = 1209,
+	FUNCTION_ID_ALL_ROOTS = 1210,
 	FUNCTION_ID_SIN = 1300,
 	FUNCTION_ID_COS = 1301,
 	FUNCTION_ID_TAN = 1302,
@@ -262,6 +290,7 @@ enum {
 	FUNCTION_ID_GCD = 1701,
 	FUNCTION_ID_LCM = 1702,
 	FUNCTION_ID_DIVISORS = 1703,
+	FUNCTION_ID_FACTORS = 1704,
 	FUNCTION_ID_SIGNUM = 1710,
 	FUNCTION_ID_ROUND = 1720,
 	FUNCTION_ID_FLOOR = 1721,
@@ -274,6 +303,7 @@ enum {
 	FUNCTION_ID_REM = 1734,
 	FUNCTION_ID_MOD = 1735,
 	FUNCTION_ID_PARALLEL = 1736,
+	FUNCTION_ID_POWER_MOD = 1737,
 	FUNCTION_ID_BERNOULLI = 1740,
 	FUNCTION_ID_TOTIENT = 1745,
 	FUNCTION_ID_RE = 1750,
@@ -316,6 +346,9 @@ enum {
 	FUNCTION_ID_IS_INTEGER = 1923,
 	FUNCTION_ID_ODD = 1924,
 	FUNCTION_ID_EVEN = 1925,
+	FUNCTION_ID_INTEGER_DIGITS = 1930,
+	FUNCTION_ID_DIGIT_GET = 1931,
+	FUNCTION_ID_DIGIT_SET = 1932,
 	FUNCTION_ID_POLYNOMIAL_UNIT = 2000,
 	FUNCTION_ID_POLYNOMIAL_PRIMPART = 2001,
 	FUNCTION_ID_POLYNOMIAL_CONTENT = 2002,
@@ -329,8 +362,12 @@ enum {
 	FUNCTION_ID_BIT_CMP = 2102,
 	FUNCTION_ID_SHIFT = 2103,
 	FUNCTION_ID_CIRCULAR_SHIFT = 2104,
+	FUNCTION_ID_BIT_SET = 2105,
+	FUNCTION_ID_BIT_GET = 2106,
+	FUNCTION_ID_SET_BITS = 2107,
 	FUNCTION_ID_FOR = 2150,
 	FUNCTION_ID_IF = 2151,
+	FUNCTION_ID_FOREACH = 2152,
 	FUNCTION_ID_TOTAL = 2200,
 	FUNCTION_ID_PERCENTILE = 2201,
 	FUNCTION_ID_MIN = 2202,
@@ -392,6 +429,7 @@ DECLARE_BUILTIN_FUNCTION(VectorFunction, FUNCTION_ID_VECTOR)
 DECLARE_BUILTIN_FUNCTION(LimitsFunction, FUNCTION_ID_LIMITS)
 DECLARE_BUILTIN_FUNCTION(RankFunction, FUNCTION_ID_RANK)
 DECLARE_BUILTIN_FUNCTION(SortFunction, FUNCTION_ID_SORT)
+DECLARE_BUILTIN_FUNCTION(FlipFunction, FUNCTION_ID_FLIP)
 DECLARE_BUILTIN_FUNCTION_M(ComponentFunction, FUNCTION_ID_COMPONENT)
 DECLARE_BUILTIN_FUNCTION_PI(DimensionFunction, FUNCTION_ID_DIMENSION)
 DECLARE_BUILTIN_FUNCTION(MatrixFunction, FUNCTION_ID_MATRIX)
@@ -418,6 +456,7 @@ DECLARE_BUILTIN_FUNCTION(EntrywiseFunction, FUNCTION_ID_ENTRYWISE)
 DECLARE_BUILTIN_FUNCTION(LoadFunction, FUNCTION_ID_LOAD)
 DECLARE_BUILTIN_FUNCTION(ExportFunction, FUNCTION_ID_EXPORT)
 DECLARE_BUILTIN_FUNCTION(GenerateVectorFunction, FUNCTION_ID_GENERATE_VECTOR)
+DECLARE_BUILTIN_FUNCTION(ColonFunction, FUNCTION_ID_COLON)
 DECLARE_BUILTIN_FUNCTION(SelectFunction, FUNCTION_ID_SELECT)
 DECLARE_BUILTIN_FUNCTION(ProcessFunction, FUNCTION_ID_PROCESS)
 DECLARE_BUILTIN_FUNCTION(ProcessMatrixFunction, FUNCTION_ID_PROCESS_MATRIX)
@@ -428,6 +467,7 @@ DECLARE_BUILTIN_FUNCTION(EntrywiseMultiplicationFunction, FUNCTION_ID_ENTRYWISE_
 DECLARE_BUILTIN_FUNCTION(EntrywiseDivisionFunction, FUNCTION_ID_ENTRYWISE_DIVISION)
 DECLARE_BUILTIN_FUNCTION(EntrywisePowerFunction, FUNCTION_ID_ENTRYWISE_POWER)
 DECLARE_BUILTIN_FUNCTION(NormFunction, FUNCTION_ID_NORM)
+DECLARE_BUILTIN_FUNCTION_MT(KroneckerProductFunction, FUNCTION_ID_KRONECKER_PRODUCT)
 
 DECLARE_BUILTIN_FUNCTION_R(SqrtFunction, FUNCTION_ID_SQRT)
 DECLARE_BUILTIN_FUNCTION(CbrtFunction, FUNCTION_ID_CBRT)
@@ -438,10 +478,12 @@ DECLARE_BUILTIN_FUNCTION_R(LogFunction, FUNCTION_ID_LOG)
 DECLARE_BUILTIN_FUNCTION_MT(LognFunction, FUNCTION_ID_LOGN)
 DECLARE_BUILTIN_FUNCTION_R3(LambertWFunction, FUNCTION_ID_LAMBERT_W)
 DECLARE_BUILTIN_FUNCTION_MT(CisFunction, FUNCTION_ID_CIS)
+DECLARE_BUILTIN_FUNCTION_R3(PowerTowerFunction, FUNCTION_ID_POWER_TOWER)
+DECLARE_BUILTIN_FUNCTION(AllRootsFunction, FUNCTION_ID_ALL_ROOTS)
 
 DECLARE_BUILTIN_FUNCTION_R2(SinFunction, FUNCTION_ID_SIN)
 DECLARE_BUILTIN_FUNCTION_R2(CosFunction, FUNCTION_ID_COS)
-DECLARE_BUILTIN_FUNCTION_R2(TanFunction, FUNCTION_ID_TAN)
+DECLARE_BUILTIN_FUNCTION_R4(TanFunction, FUNCTION_ID_TAN)
 DECLARE_BUILTIN_FUNCTION_R1(AsinFunction, FUNCTION_ID_ASIN)
 DECLARE_BUILTIN_FUNCTION_R1(AcosFunction, FUNCTION_ID_ACOS)
 DECLARE_BUILTIN_FUNCTION_R2(AtanFunction, FUNCTION_ID_ATAN)
@@ -483,19 +525,19 @@ DECLARE_BUILTIN_FUNCTION_R2(IGammaFunction, FUNCTION_ID_I_GAMMA)
 DECLARE_BUILTIN_FUNCTION(IncompleteBetaFunction, FUNCTION_ID_INCOMPLETE_BETA)
 DECLARE_BUILTIN_FUNCTION(InverseIncompleteBetaFunction, FUNCTION_ID_INVERSE_INCOMPLETE_BETA)
 
-DECLARE_BUILTIN_FUNCTION(DeriveFunction, FUNCTION_ID_DIFFERENTIATE)
-DECLARE_BUILTIN_FUNCTION(IntegrateFunction, FUNCTION_ID_INTEGRATE)
-DECLARE_BUILTIN_FUNCTION(LimitFunction, FUNCTION_ID_LIMIT)
-DECLARE_BUILTIN_FUNCTION(MonteCarloFunction, FUNCTION_ID_MONTE_CARLO)
-DECLARE_BUILTIN_FUNCTION(RombergFunction, FUNCTION_ID_ROMBERG)
+DECLARE_BUILTIN_FUNCTION_MT(DeriveFunction, FUNCTION_ID_DIFFERENTIATE)
+DECLARE_BUILTIN_FUNCTION_MT(IntegrateFunction, FUNCTION_ID_INTEGRATE)
+DECLARE_BUILTIN_FUNCTION_MT(LimitFunction, FUNCTION_ID_LIMIT)
+DECLARE_BUILTIN_FUNCTION_MT(MonteCarloFunction, FUNCTION_ID_MONTE_CARLO)
+DECLARE_BUILTIN_FUNCTION_MT(RombergFunction, FUNCTION_ID_ROMBERG)
 
-DECLARE_BUILTIN_FUNCTION(SumFunction, FUNCTION_ID_SUM)
-DECLARE_BUILTIN_FUNCTION(ProductFunction, FUNCTION_ID_PRODUCT)
+DECLARE_BUILTIN_FUNCTION_MT(SumFunction, FUNCTION_ID_SUM)
+DECLARE_BUILTIN_FUNCTION_MT(ProductFunction, FUNCTION_ID_PRODUCT)
 DECLARE_BUILTIN_FUNCTION(SolveFunction, FUNCTION_ID_SOLVE)
 DECLARE_BUILTIN_FUNCTION(SolveMultipleFunction, FUNCTION_ID_SOLVE_MULTIPLE)
 DECLARE_BUILTIN_FUNCTION(DSolveFunction, FUNCTION_ID_D_SOLVE)
-DECLARE_BUILTIN_FUNCTION(NewtonRaphsonFunction, FUNCTION_ID_NEWTON_RAPHSON)
-DECLARE_BUILTIN_FUNCTION(SecantMethodFunction, FUNCTION_ID_SECANT_METHOD)
+DECLARE_BUILTIN_FUNCTION_MT(NewtonRaphsonFunction, FUNCTION_ID_NEWTON_RAPHSON)
+DECLARE_BUILTIN_FUNCTION_MT(SecantMethodFunction, FUNCTION_ID_SECANT_METHOD)
 
 DECLARE_BUILTIN_FUNCTION_R(FactorialFunction, FUNCTION_ID_FACTORIAL)
 DECLARE_BUILTIN_FUNCTION_R(DoubleFactorialFunction, FUNCTION_ID_DOUBLE_FACTORIAL)
@@ -508,12 +550,13 @@ DECLARE_BUILTIN_FUNCTION_R2(ArgFunction, FUNCTION_ID_ARG)
 
 DECLARE_BUILTIN_FUNCTION_R(AbsFunction, FUNCTION_ID_ABS)
 DECLARE_BUILTIN_FUNCTION_MT(GcdFunction, FUNCTION_ID_GCD)
+DECLARE_BUILTIN_FUNCTION(FactorsFunction, FUNCTION_ID_FACTORS)
 DECLARE_BUILTIN_FUNCTION_MT(LcmFunction, FUNCTION_ID_LCM)
 DECLARE_BUILTIN_FUNCTION(DivisorsFunction, FUNCTION_ID_DIVISORS)
 DECLARE_BUILTIN_FUNCTION_MT(PrimeCountFunction, FUNCTION_ID_PRIME_COUNT)
 DECLARE_BUILTIN_FUNCTION_MT(IsPrimeFunction, FUNCTION_ID_IS_PRIME)
 DECLARE_BUILTIN_FUNCTION_MT(NthPrimeFunction, FUNCTION_ID_NTH_PRIME)
-DECLARE_BUILTIN_FUNCTION_MT(PrimesFunction, FUNCTION_ID_PRIMES)
+DECLARE_BUILTIN_FUNCTION(PrimesFunction, FUNCTION_ID_PRIMES)
 DECLARE_BUILTIN_FUNCTION_MT(PrevPrimeFunction, FUNCTION_ID_PREV_PRIME)
 DECLARE_BUILTIN_FUNCTION_MT(NextPrimeFunction, FUNCTION_ID_NEXT_PRIME)
 DECLARE_BUILTIN_FUNCTION_R(SignumFunction, FUNCTION_ID_SIGNUM)
@@ -527,6 +570,7 @@ DECLARE_BUILTIN_FUNCTION_MT(IntFunction, FUNCTION_ID_INT)
 DECLARE_BUILTIN_FUNCTION_MT(FracFunction, FUNCTION_ID_FRAC)
 DECLARE_BUILTIN_FUNCTION_MT(RemFunction, FUNCTION_ID_REM)
 DECLARE_BUILTIN_FUNCTION_MT(ModFunction, FUNCTION_ID_MOD)
+DECLARE_BUILTIN_FUNCTION_MT(PowerModFunction, FUNCTION_ID_POWER_MOD)
 DECLARE_BUILTIN_FUNCTION_MT(BernoulliFunction, FUNCTION_ID_BERNOULLI)
 DECLARE_BUILTIN_FUNCTION_MT(TotientFunction, FUNCTION_ID_TOTIENT)
 DECLARE_BUILTIN_FUNCTION(ParallelFunction, FUNCTION_ID_PARALLEL)
@@ -544,6 +588,10 @@ DECLARE_BUILTIN_FUNCTION(RomanFunction, FUNCTION_ID_ROMAN)
 DECLARE_BUILTIN_FUNCTION(BijectiveFunction, FUNCTION_ID_BIJECTIVE)
 DECLARE_BUILTIN_FUNCTION(BinaryDecimalFunction, FUNCTION_ID_BINARY_DECIMAL)
 
+DECLARE_BUILTIN_FUNCTION(IntegerDigitsFunction, FUNCTION_ID_INTEGER_DIGITS)
+DECLARE_BUILTIN_FUNCTION(DigitGetFunction, FUNCTION_ID_DIGIT_GET)
+DECLARE_BUILTIN_FUNCTION(DigitSetFunction, FUNCTION_ID_DIGIT_SET)
+
 DECLARE_BUILTIN_FUNCTION(IEEE754FloatFunction, FUNCTION_ID_IEEE754_FLOAT)
 DECLARE_BUILTIN_FUNCTION(IEEE754FloatBitsFunction, FUNCTION_ID_IEEE754_FLOAT_BITS)
 DECLARE_BUILTIN_FUNCTION(IEEE754FloatComponentsFunction, FUNCTION_ID_IEEE754_FLOAT_COMPONENTS)
@@ -569,11 +617,15 @@ DECLARE_BUILTIN_FUNCTION(LDegreeFunction, FUNCTION_ID_L_DEGREE)
 DECLARE_BUILTIN_FUNCTION(BitXorFunction, FUNCTION_ID_BIT_XOR)
 DECLARE_BUILTIN_FUNCTION_B(XorFunction, FUNCTION_ID_XOR)
 DECLARE_BUILTIN_FUNCTION(BitCmpFunction, FUNCTION_ID_BIT_CMP)
+DECLARE_BUILTIN_FUNCTION(BitSetFunction, FUNCTION_ID_BIT_SET)
+DECLARE_BUILTIN_FUNCTION(BitGetFunction, FUNCTION_ID_BIT_GET)
+DECLARE_BUILTIN_FUNCTION(SetBitsFunction, FUNCTION_ID_SET_BITS)
 DECLARE_BUILTIN_FUNCTION(ShiftFunction, FUNCTION_ID_SHIFT)
 DECLARE_BUILTIN_FUNCTION(CircularShiftFunction, FUNCTION_ID_CIRCULAR_SHIFT)
 
 DECLARE_BUILTIN_FUNCTION(ForFunction, FUNCTION_ID_FOR)
 DECLARE_BUILTIN_FUNCTION_M(IFFunction, FUNCTION_ID_IF)
+DECLARE_BUILTIN_FUNCTION(ForEachFunction, FUNCTION_ID_FOREACH)
 
 DECLARE_BUILTIN_FUNCTION(TotalFunction, FUNCTION_ID_TOTAL)
 DECLARE_BUILTIN_FUNCTION(PercentileFunction, FUNCTION_ID_PERCENTILE)
@@ -624,7 +676,7 @@ DECLARE_BUILTIN_FUNCTION(SaveFunction, FUNCTION_ID_SAVE)
 DECLARE_BUILTIN_FUNCTION(RegisterFunction, FUNCTION_ID_REGISTER)
 DECLARE_BUILTIN_FUNCTION(StackFunction, FUNCTION_ID_STACK)
 DECLARE_BUILTIN_FUNCTION(CommandFunction, FUNCTION_ID_COMMAND)
-DECLARE_BUILTIN_FUNCTION(PlotFunction, FUNCTION_ID_PLOT)
+DECLARE_BUILTIN_FUNCTION_P(PlotFunction, FUNCTION_ID_PLOT)
 DECLARE_BUILTIN_FUNCTION_R(IntervalFunction, FUNCTION_ID_INTERVAL)
 DECLARE_BUILTIN_FUNCTION(UncertaintyFunction, FUNCTION_ID_UNCERTAINTY)
 DECLARE_BUILTIN_FUNCTION(GeographicDistanceFunction, FUNCTION_ID_GEO_DISTANCE)
