@@ -1,7 +1,7 @@
 /*
     Qalculate
 
-    Copyright (C) 2019  Hanna Knutsson (hanna.knutsson@protonmail.com)
+    Copyright (C) 2019-2024  Hanna Knutsson (hanna.knutsson@protonmail.com)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -66,7 +66,7 @@ class Calculator_p {
 		long int custom_input_base_i;
 		Unit *local_currency;
 		int use_binary_prefixes;
-		MathFunction *f_cis, *f_erfi, *f_fresnels, *f_fresnelc, *f_dot, *f_times, *f_rdivide, *f_power, *f_parallel, *f_vertcat, *f_horzcat, *f_secant, *f_newton;
+		MathFunction *f_cis, *f_erfi, *f_fresnels, *f_fresnelc, *f_dot, *f_times, *f_rdivide, *f_power, *f_parallel, *f_vertcat, *f_horzcat, *f_secant, *f_newton, *f_colon;
 		Unit *u_byn;
 		Unit *u_kelvin, *u_rankine, *u_celsius, *u_fahrenheit;
 		Unit *custom_angle_unit;
@@ -79,6 +79,7 @@ class Calculator_p {
 		bool matlab_matrices;
 		bool persistent_plot;
 		bool concise_uncertainty_input;
+		bool simplified_percentage_used;
 		int exchange_rates_url3;
 		long int fixed_denominator;
 };
