@@ -665,7 +665,7 @@ void NowVariable::calculate(MathStructure &m) const {
 
 #include <fstream>
 
-void UptimeVariable:: calculate(MathStructure &m) const {
+void UptimeVariable::calculate(MathStructure &m) const {
 #ifndef DISABLE_INSECURE
 	Number nr;
 #	ifdef __linux__
@@ -686,6 +686,11 @@ void UptimeVariable:: calculate(MathStructure &m) const {
 	m = nr;
 	Unit *u = CALCULATOR->getUnit("s");
 	if(u) m *= u;
+#else
+	CALCULATOR->error(true, _("%s is disabled when %s is compiled with \"%s\" configure option."), preferredName().name.c_str(), "libqalculate", "--disable-insecure", NULL);
+	m = nr_zero;
+	Unit *u = CALCULATOR->getUnit("s");
+	if(u) m *= u;
 #endif
 }
 UptimeVariable::UptimeVariable() : DynamicVariable("", "uptime") {
