@@ -1922,10 +1922,6 @@ int main(int argc, char *argv[]) {
 	evalops.structuring = STRUCTURING_SIMPLIFY;
 	//evalops.approximation = APPROXIMATION_EXACT;
 
-	for(size_t i = 0; i < 100000; i++) {
-		cout << rnd_expression(false, false, 5, 4, false, false, false, false, false) << endl;
-	}
-return 0;
 	/*po.use_unicode_signs = true;
 	po.number_fraction_format = FRACTION_DECIMAL;
 	bool b_approx = false;
@@ -1966,9 +1962,9 @@ return 0;
 	mstruct.eval(evalops);
 	cout << mstruct << endl;*/
 	//speed_test();
-	/*test_integration();
+	test_integration();
 	cout << successes << ":" << imaginary << endl;
-	return 0;*/
+	return 0;
 	//test_intervals(true);
 
 	/*Number nr;
